summaryrefslogtreecommitdiff
path: root/lang/squeak2/files/patch-aa
blob: 874e2c8881a87fc28d63a977bdeea51a528e5ad8 (plain) (blame)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
--- /usr/ports/lang/squeak2/work/2.3/src/sqXWindow.c	Tue Feb  9 15:25:30 1999
+++ src/sqXWindow.c	Thu Mar  4 09:42:26 1999
@@ -88,7 +88,7 @@
 char shortImageName[MAXPATHLEN+1];	/* just the base name */
 char vmPath[MAXPATHLEN+1];		/* full path to interpreter's directory */
 
-int initialHeapSize;			/* 5 megabytes by default */
+int initialHeapSize;			/* 20 megabytes by default */
 
 int    initialArgc;
 char **initialArgv;
@@ -2494,7 +2494,7 @@
   if ((ev= getenv("SQUEAK_MEMORY")))
     initialHeapSize= strtobkm(ev);
   else
-    initialHeapSize= 5*1024*1024;	/* 5 megabytes by default */
+    initialHeapSize= 20*1024*1024;	/* 20 megabytes by default */
 
   if (getenv("SQUEAK_LAZY"))
     sleepWhenUnmapped= 1;